# semaphore

![Versions](https://img.shields.io/badge/python->3.7-blue)
[![Documentation Status](https://readthedocs.org/projects/semaphore/badge/?version=latest)](https://semaphore.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/sdss/semaphore/branch/main/graph/badge.svg)](https://codecov.io/gh/sdss/semaphore)

Communicating with flags
